# History

- [v0.1.1.a6.dev1](#v011a6dev1)
  - [Changes](#changes)
- [v0.1.1.a5.dev1](#v011a5dev1)
  - [Changes](#changes-1)
- [v0.1.1.a4.dev1](#v011a4dev1)
  - [Changes](#changes-2)
- [v0.1.1a3.dev1](#v011a3dev1)
  - [Changes](#changes-3)
- [v0.1.1a2.dev1](#v011a2dev1)
  - [Changes](#changes-4)
- [v0.1.1a1.dev1](#v011a1dev1)
  - [Deprecations](#deprecations)
  - [Changes](#changes-5)
- [v0.0.2.dev3](#v002dev3)
  - [Misc](#misc)
- [v0.0.2.dev2](#v002dev2)
  - [Changes](#changes-6)
  - [Misc](#misc-1)
- [v0.0.2.dev1](#v002dev1)
  - [Changes](#changes-7)
- [v0.0.1.dev1](#v001dev1)
  - [Changes](#changes-8)

## v0.1.1.a6.dev1

10 June 2022

### Changes

- Add support for singleton mode.

## v0.1.1.a5.dev1

09 June 2022

### Changes

- the repair log name settings.

## v0.1.1.a4.dev1

06 June 2022

### Changes

- the reject config dependency
- the repair and guarantee possible exceptions in the logging_logger

## v0.1.1a3.dev1

04 June 2022

### Changes

- Add logging support for multi process environment.

## v0.1.1a2.dev1

02 June 2022

### Changes

- the enable strict mode adaptation py code.
- the fixes Python TypeError: coercing to Unicode: need string or buffer, tuple found.

## v0.1.1a1.dev1

30 May 2022

### Deprecations

- the mark deprecated API with `com.dvsnier.config.common_config` module.
- the mark deprecated API with `com.dvsnier.config.conf`.

### Changes

- the support for multi module logging.

## v0.0.2.dev3

25 February 2022

### Misc

- the eliminate nonconforming normative notes.

## v0.0.2.dev2

27 August 2021

### Changes

- Adjust and optimize cfg module class instances to object instances.

### Misc

- the cfg module, remove redundant notes.

## v0.0.2.dev1

07 July 2021

### Changes

- Add support for boolean and number type in cfg module.
- Add optimization to config module.

## v0.0.1.dev1

07 June 2021

### Changes

- the basic functions.
